Socket.IO Dashboard Namespace Diagnostic

# 🔍 Socket.IO Dashboard Namespace Diagnostic

Server: http://localhost:8765 | Started:

### 🔧 Connection Controls

Server URL:

### /system namespace

DISCONNECTED

### /session namespace

DISCONNECTED

### /claude namespace

DISCONNECTED

### /agent namespace

DISCONNECTED

### /hook namespace

DISCONNECTED

### /todo namespace

DISCONNECTED

### /memory namespace

DISCONNECTED

### /log namespace

DISCONNECTED
0
Connected Namespaces
0
Events Received
0
Connection Errors
0s
Uptime

### 📜 Event Log (Latest First)